@@ -123,8 +123,8 @@ class FFMPEG_VideoReader:
 
         else:
 
-            result = np.fromstring(s, dtype='uint8').\
-                         reshape((h, w, len(s)//(w*h)))
+            result = np.fromstring(s, dtype='uint8')
+            result.shape =(h, w, len(s)//(w*h)) # reshape((h, w, len(s)//(w*h)))
             self.lastread = result
 
         return result
@@ -265,12 +265,18 @@ def ffmpeg_parse_infos(filename, print_infos=False, check_duration=True):
 
     if result['video_found']:
 
-        line = lines_video[0]
 
-        # get the size, of the form 460x320 (w x h)
-        match = re.search(" [0-9]*x[0-9]*(,| )", line)
-        s = list(map(int, line[match.start():match.end()-1].split('x')))
-        result['video_size'] = s
+        try:
+            line = lines_video[0]
+
+            # get the size, of the form 460x320 (w x h)
+            match = re.search(" [0-9]*x[0-9]*(,| )", line)
+            s = list(map(int, line[match.start():match.end()-1].split('x')))
+            result['video_size'] = s
+        except:
+            raise (("MoviePy error: failed to read video dimensions in file %s.\n"
+                           "Here are the file infos returned by ffmpeg:\n\n%s")%(
+                              filename, infos))
 
 
         # get the frame rate. Sometimes it's 'tbr', sometimes 'fps', sometimes
